# coding: utf-8

# flake8: noqa
"""
    Tinq AI V2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Contact: boulama@tinq.ai
    A Python wrapper for the Tinq.ai API - an easy-to-use text analysis and natural language processing toolkit.
    Generated by OpenAPI Generator

"""  # noqa: E501


# import models into model package
